start_log_thread

Function start_log_thread 

pub fn start_log_thread(
    idle_iteration_cooldown_in_milli: u64,
    working_iteration_cooldown_in_milli: u64,
)
Launch a thread that will handle logging operations. Allow to log messages asynchronously, which can be useful for performance in applications with high logging demands.

Recomended when using log server: https://github.com/eVisualUser/log-server

Parameters

-‘idle_iteration_cooldown_in_milli’ - The cooldown time in milliseconds when the thread is idle (not processing requests).

-‘working_iteration_cooldown_in_milli’ - The cooldown time in milliseconds when the thread is processing requests.